#
# spec file for package python-nbformat
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-nbformat
Version:        4.4.0
%define doc_ver 4.4.0
Release:        bp153.1.21
Summary:        The Jupyter Notebook format
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jupyter/nbformat
Source:         https://files.pythonhosted.org/packages/source/n/nbformat/nbformat-%{version}.tar.gz
Source1:        https://buildmedia.readthedocs.org/media/pdf/nbformat/%{doc_ver}/nbformat.pdf
Source2:        https://buildmedia.readthedocs.org/media/htmlzip/nbformat/%{doc_ver}/nbformat.zip
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# SECTION test requirements
BuildRequires:  %{python_module ipython_genutils}
BuildRequires:  %{python_module jsonschema > 2.5.0}
BuildRequires:  %{python_module jupyter_core}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testpath}
BuildRequires:  %{python_module traitlets >= 4.1}
# /SECTION
Requires:       jupyter-nbformat = %{version}
Requires:       python-ipython_genutils
Requires:       python-jsonschema > 2.5.0
Requires:       python-jupyter_core
Requires:       python-traitlets >= 4.1
Provides:       python-jupyter_nbformat = %{version}
# Change <= to < with next release after 4.4
Obsoletes:      python-jupyter_nbformat <= %{version}
BuildArch:      noarch
%python_subpackages

%description
This package contains the base implementation of the Jupyter Notebook format,
and Python APIs for working with notebooks.

This package provides the python interface.

%package     -n jupyter-nbformat
Summary:        The Jupyter Notebook format
Requires:       jupyter-jupyter_core
Requires:       python3-nbformat = %{version}
# uncomment with next release after 4.4:
# Conflicts:      python3-jupyter_nbformat <= 4.5

%description -n jupyter-nbformat
This package contains the base implementation of the Jupyter Notebook format,
and Python APIs for working with notebooks.

This package provides the jupyter components.

%package     -n jupyter-nbformat-doc
Summary:        Documentation for the Jupyter Notebook format
Requires:       jupyter-nbformat = %{version}
Provides:       python-jupyter_nbformat-doc = %{version}
Obsoletes:      python-jupyter_nbformat-doc <= %{version}
Provides:       %{python_module jupyter_nbformat-doc = %{version}}
Obsoletes:      %{python_module jupyter_nbformat-doc <= %{version}}
Provides:       %{python_module nbformat-doc = %{version}}
Provides:       python-nbformat-html = %{version}
Provides:       python-nbformat-pdf = %{version}
Obsoletes:      python-nbformat-html < %{version}
Obsoletes:      python-nbformat-pdf < %{version}

%description -n jupyter-nbformat-doc
This package contains documentation and help files for the Jupyter
Notebook format

%prep
%setup -q -n nbformat-%{version}
unzip %{SOURCE2} -d docs
mv docs/nbformat-* docs/html
rm docs/html/.buildinfo

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

mkdir -p %{buildroot}%{_docdir}/jupyter-nbformat

cp %{SOURCE1} %{buildroot}%{_docdir}/jupyter-nbformat/
cp -r docs/html %{buildroot}%{_docdir}/jupyter-nbformat/

%fdupes %{buildroot}%{_docdir}/jupyter-nbformat/

%check
%pytest -k "not TestNotary and not SQLiteSignatureStoreTests"

%files %{python_files}
%license COPYING.md
%doc README.md
%{python_sitelib}/nbformat-%{version}-py*.egg-info
%{python_sitelib}/nbformat/
# Move this to jupyter-nbformat with next release (after 4.4)
%python3_only %{_bindir}/jupyter-trust

%files -n jupyter-nbformat
%license COPYING.md

%files -n jupyter-nbformat-doc
%license COPYING.md
%{_docdir}/jupyter-nbformat/

%changelog
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Merge everything into one spec file to simplify maintenance.
* Fri May 17 2019 Todd R <toddrme2178@gmail.com>
- Move executable to python package to avoid conflicts with old
  naming scheme.  It should be moved back with the next release.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
- Rename doc package to match jupyter package name.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 4.4.0
  * Explicitly state that metadata fields can be ignored.
  * Introduce official jupyter namespace inside metadata (``metadata.jupyter``).
  * Introduce ``source_hidden`` and ``outputs_hidden`` as official front-end
    metadata fields to indicate hiding source and outputs areas. **NB**: These
    fields should not be used to hide elements in exported formats.
  * Fix ending the redundant storage of signatures in the signature database.
  * :func:`nbformat.validate` can be set to not raise a ValidationError if
    additional properties are included.
  * Fix for errors with connecting and backing up the signature database.
  * Dict-like objects added to NotebookNode attributes are now transformed to be
    NotebookNode objects; transformation also works for `.update()`.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Clean up update-alternatives usage.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3.0
  * A new pluggable ``SignatureStore`` class allows specifying different ways to
    record the signatures of trusted notebooks. The default is still an SQLite
    database. See :ref:`pluggable_signature_store` for more information.
  * :func:`nbformat.read` and :func:`nbformat.write` accept file paths as bytes
    as well as unicode.
  * Fix for calling :func:`nbformat.validate` on an empty dictionary.
  * Fix for running the tests where the locale makes ASCII the default encoding.
- Update to 4.2.0
  * Update nbformat spec version to 4.2, allowing JSON outputs to have any JSONable type,  not just ``object``,
    and mime-types of the form ``application/anything+json``.
  * Define basics of ``authors`` in notebook metadata.
    ``nb.metadata.authors`` shall be a list of objects with the property ``name``, a string of each author's full name.
  * Update use of traitlets API to require traitlets 4.1.
  * Support trusting notebooks on stdin with ``cat notebook | jupyter trust``
- Update to 4.1.0
  * Update nbformat spec version to 4.1, adding support for attachments on markdown and raw cells.
  * Catch errors opening trust database, falling back on ``:memory:`` if the database cannot be opened.
- Create doc subpackage
* Mon Oct 12 2015 toddrme2178@gmail.com
- update to version 4.0.1:
  * setuptools entrypoint
  * Add label to format docs for cross referencing
  * ensure `--version` output has actual version
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Thu Aug 13 2015 toddrme2178@gmail.com
- Initial version
